
API Documentation
=================

Core Application
----------------

.. automodule:: fpvgcc.fpv
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: fpvgcc.gccMemoryMap
    :members:
    :undoc-members:
    :show-inheritance:

Underlying Data Structures
--------------------------

.. automodule:: fpvgcc.datastructures.ntreeSize
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: fpvgcc.datastructures.ntree
    :members:
    :undoc-members:
    :show-inheritance:

User Interfaces
---------------

.. automodule:: fpvgcc.cli
    :members:
    :undoc-members:
    :show-inheritance:

Toolchain Profiles
------------------

.. automodule:: fpvgcc.profiles.context
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: fpvgcc.profiles.guess
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: fpvgcc.profiles.gcc_msp430
    :members:
    :undoc-members:
    :show-inheritance:
